==> scala-relay-compiler-0.6.13.tgz: package/lib/transforms/SJSTransform.js <==
'use strict';

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

const GraphQLCompilerContext = require('relay-compiler/lib/GraphQLCompilerContext');
const GraphQLIRTransformer = require('relay-compiler/lib/GraphQLIRTransformer');

const invariant = require('invariant');
const stableJSONStringify = require('relay-compiler/lib/stableJSONStringify');
// const stableJSONStringify = require('stableJSONStringify');

const {
  CompilerContext,
  IRTransformer,
  getLiteralArgumentValues
} = require('relay-compiler/lib/GraphQLCompilerPublic');

function sjsTransform(context) {

  return IRTransformer.transform(context, {
    Fragment: visitFragment,
    FragmentSpread: visitFragmentSpread
  }, () => ({}));
}

const SJS = 'sjs';
const WITH = 'with';

function visitFragment(fragment) {
  let transformedFrag = this.traverse(fragment);
  const relayDirective = transformedFrag.directives.find(({ name }) => name === SJS);
  if (!relayDirective) {
    return transformedFrag;
  }

  const arg = getLiteralArgumentValues(relayDirective.args);

  return _extends({}, transformedFrag, {
    directives: transformedFrag.directives.filter(directive => directive.name !== SJS),
    metadata: _extends({}, transformedFrag.metadata || {}, arg)
  });
}

function visitFragmentSpread(fragment) {
  let transformedFrag = this.traverse(fragment);
  const relayDirective = transformedFrag.directives.find(({ name }) => name === SJS);
  if (!relayDirective) {
    return transformedFrag;
  }

  const arg = getLiteralArgumentValues(relayDirective.args);

  return _extends({}, transformedFrag, {
    directives: transformedFrag.directives.filter(directive => directive.name !== SJS),
    metadata: _extends({}, transformedFrag.metadata || {}, arg)
  });
}

function filterDirectivesTransform(context) {
  return GraphQLIRTransformer.transform(context, { Directive: visitDirective }, () => ({}));
}

/**
 *
 * Skip directives not defined in the original schema.
 */
function visitDirective(directive) {
  if (directive.name === SJS) return null;
  return directive;
}

module.exports = {
  transform: sjsTransform,
  transformRemoveSjs: filterDirectivesTransform
};

==> scala-relay-compiler-0.9.0.tgz: package/lib/transforms/SJSTransform.js <==
'use strict';

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

const GraphQLCompilerContext = require('relay-compiler/lib/GraphQLCompilerContext');
const GraphQLIRTransformer = require('relay-compiler/lib/GraphQLIRTransformer');

const invariant = require('invariant');

const {
  CompilerContext,
  IRTransformer,
  getLiteralArgumentValues
} = require('relay-compiler/lib/GraphQLCompilerPublic');

function sjsTransform(context) {

  return IRTransformer.transform(context, {
    Fragment: visitField,
    FragmentSpread: visitField,
    InlineFragment: visitField,
    LinkedField: visitField
  }, () => ({}));
}

const SJS = 'scalajs';

function visitField(fragment) {
  let transformedFrag = this.traverse(fragment);
  const relayDirective = transformedFrag.directives.find(({ name }) => name === SJS);
  if (!relayDirective) {
    return transformedFrag;
  }

  const arg = getLiteralArgumentValues(relayDirective.args);

  return _extends({}, transformedFrag, {
    directives: transformedFrag.directives.filter(directive => directive.name !== SJS),
    metadata: _extends({}, transformedFrag.metadata || {}, arg)
  });
}

function filterDirectivesTransform(context) {
  return GraphQLIRTransformer.transform(context, { Directive: visitDirective }, () => ({}));
}

/**
 *
 * Skip directives not defined in the original schema.
 */
function visitDirective(directive) {
  if (directive.name === SJS) return null;
  return directive;
}

module.exports = {
  transform: sjsTransform,
  transformRemoveSjs: filterDirectivesTransform
};
